[Swift-commit] r4263 - in trunk/tests: . html mpi persistent-coasters

wozniak at ci.uchicago.edu wozniak at ci.uchicago.edu
Mon Apr 4 13:00:30 CDT 2011


Author: wozniak
Date: 2011-04-04 13:00:30 -0500 (Mon, 04 Apr 2011)
New Revision: 4263

Added:
   trunk/tests/run-suite.sh
Removed:
   trunk/tests/run-nightly.sh
Modified:
   trunk/tests/README
   trunk/tests/html/header.html
   trunk/tests/meta.sh
   trunk/tests/mpi/README.txt
   trunk/tests/persistent-coasters/000-sanity.test.sh
   trunk/tests/sitetester
   trunk/tests/suite.sh
Log:
Rename nightly.sh to suite.sh


Modified: trunk/tests/README
===================================================================
--- trunk/tests/README	2011-04-04 17:57:09 UTC (rev 4262)
+++ trunk/tests/README	2011-04-04 18:00:30 UTC (rev 4263)
@@ -1,13 +1,13 @@
-nightly.sh:
-	See nightly.sh for usage
+suite.sh:
+	See suite.sh for usage
 
-run-nightly.sh:
-	wrapper for nightly.sh
+run-suite.sh:
+	wrapper for suite.sh
 	env variables set may be customized by user
 
 meta.sh:
-	wrapper for run-nightly.sh
-	used to execute run-nightly/nightly.sh from a remote site using ssh
+	wrapper for run-suite.sh
+	used to execute run-suite/suite.sh from a remote site using ssh
 	example usage:
 		 meta.sh login.pads.ci.uchicago.edu /home/skenny/swift_runs/tests sites/pads-pbs-coasters.sh
 

Modified: trunk/tests/html/header.html
===================================================================
--- trunk/tests/html/header.html	2011-04-04 17:57:09 UTC (rev 4262)
+++ trunk/tests/html/header.html	2011-04-04 18:00:30 UTC (rev 4263)
@@ -1,6 +1,6 @@
 <html>
   <head>
-    <title>Swift nightly integration tests and build (_DATE_ _TIME_)
+    <title>Swift integration tests and build (_DATE_ _TIME_)
     </title>
     <style type="text/css">
       a:link {color:black}
@@ -16,7 +16,7 @@
     </style>
   </head>
   <body>
-    <h1>Swift nightly integration tests and build</h1>
+    <h1>Swift integration tests and build</h1>
     <ul>
       <li>Date: _DATE_</li>
       <li>Time: _TIME_</li>

Modified: trunk/tests/meta.sh
===================================================================
--- trunk/tests/mpi/README.txt	2011-04-04 17:57:09 UTC (rev 4262)
+++ trunk/tests/mpi/README.txt	2011-04-04 18:00:30 UTC (rev 4263)
@@ -1,6 +1,6 @@
 
 Test MPICH/Coasters integration
 
-Be sure the correct MPICH is in your PATH before running nightly.sh
+Be sure the correct MPICH is in your PATH before running suite.sh
 
 See: http://www.ci.uchicago.edu/wiki/bin/view/SWFT/CoastersMpi

Modified: trunk/tests/persistent-coasters/000-sanity.test.sh
===================================================================
--- trunk/tests/persistent-coasters/000-sanity.test.sh	2011-04-04 17:57:09 UTC (rev 4262)
+++ trunk/tests/persistent-coasters/000-sanity.test.sh	2011-04-04 18:00:30 UTC (rev 4263)
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# This is just a sanity check for the nightly.sh shell script test
+# This is just a sanity check for the suite.sh shell script test
 # mechanics
 
 echo sane

Deleted: trunk/tests/run-nightly.sh
===================================================================
--- trunk/tests/run-nightly.sh	2011-04-04 17:57:09 UTC (rev 4262)
+++ trunk/tests/run-nightly.sh	2011-04-04 18:00:30 UTC (rev 4263)
@@ -1,23 +0,0 @@
-#!/bin/bash
-
-# sets up environment and runs nightly.sh
-# given a groupslistfile, will run nightly.sh on that site
-
-GROUPSLISTFILE=$1 # E.g., groups/group-all-local.sh
-
-# user-specific variables
-
-export WORK=$2
-export QUEUE=$3
-export PROJECT=$4
-
-# branch testing
-
-export COG_VERSION=$5
-export SWIFT_VERSION=$6
-
-#$2/nightly.sh -g $GROUPSLISTFILE
-
-$2/nightly.sh -g $GROUPSLISTFILE
-
-exit 0

Copied: trunk/tests/run-suite.sh (from rev 4251, trunk/tests/run-nightly.sh)
===================================================================
--- trunk/tests/run-suite.sh	                        (rev 0)
+++ trunk/tests/run-suite.sh	2011-04-04 18:00:30 UTC (rev 4263)
@@ -0,0 +1,23 @@
+#!/bin/bash
+
+# sets up environment and runs suite.sh
+# given a groupslistfile, will run suite.sh on that site
+
+GROUPSLISTFILE=$1 # E.g., groups/group-all-local.sh
+
+# user-specific variables
+
+export WORK=$2
+export QUEUE=$3
+export PROJECT=$4
+
+# branch testing
+
+export COG_VERSION=$5
+export SWIFT_VERSION=$6
+
+#$2/suite.sh -g $GROUPSLISTFILE
+
+$2/suite.sh -g $GROUPSLISTFILE
+
+exit 0

Modified: trunk/tests/sitetester
===================================================================
--- trunk/tests/sitetester	2011-04-04 17:57:09 UTC (rev 4262)
+++ trunk/tests/sitetester	2011-04-04 18:00:30 UTC (rev 4263)
@@ -3,10 +3,10 @@
 import commands
 import os
 
-# the workdir for a given site needs to exist on the site you're testing 
-# and should contain run-nightly & nightly.sh
-# this script will ssh onto the site, pass run-nightly the necesary variables
-# for running nightly.sh
+# the workdir for a given site needs to exist on the site you're testing
+# and should contain run-suite & suite.sh
+# this script will ssh onto the site, pass run-suite the necesary variables
+# for running suite.sh
 
 class Site:
 
@@ -18,16 +18,16 @@
         self.project = project
 
     def testSite(self,cogv,swiftv,test_type):
-            cmdline = self.logintype+" "+self.login+" "+self.workdir+"/run-nightly.sh "+self.workdir+"/"+test_type+" "+self.workdir+" "+self.queue+" "+self.project+" "+cogv+" "+swiftv
+            cmdline = self.logintype+" "+self.login+" "+self.workdir+"/run-suite.sh "+self.workdir+"/"+test_type+" "+self.workdir+" "+self.queue+" "+self.project+" "+cogv+" "+swiftv
             print "running......"+cmdline
             res = commands.getoutput(cmdline)
             print res
             cmdline2 =  "scp -r "+s+":"+rundir+" ."
             res2 = commands.getoutput(cmdline)
-    
 
-        
 
+
+
 #---------------------main--------------------------------------------------------
 
 sites = []
@@ -51,7 +51,7 @@
 # loop over all or run single
 
 sites[1].testSite(cogv,swiftv,test_type)
-sites[2].testSite(cogv,swiftv,test_type)    
+sites[2].testSite(cogv,swiftv,test_type)
 
 
 

Modified: trunk/tests/suite.sh
===================================================================
--- trunk/tests/meta.sh	2011-04-04 17:57:09 UTC (rev 4262)
+++ trunk/tests/meta.sh	2011-04-04 18:00:30 UTC (rev 4263)
@@ -1,6 +1,6 @@
 #!/bin/bash
 
 # runs run-nightly.sh (wrapper for nightly.sh) on a given site based on login
 
 SITE_LOGIN=$1 # e.g. login.pads.ci.uchicago.edu
 
@@ -12,7 +12,7 @@
 
 RUNDIR=run-$( date +"%Y-%m-%d" )
 
-ssh $SITE_LOGIN $DIR/run-nightly.sh $DIR/$TEST
+ssh $SITE_LOGIN $DIR/run-suite.sh $DIR/$TEST
 scp -r $SITE_LOGIN:$RUNDIR .
 
 exit 0
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# runs run-nightly.sh (wrapper for nightly.sh) on a given site based on login
+# runs run-suite.sh (wrapper for suite.sh) on a given site based on login
 
 SITE_LOGIN=$1 # e.g. login.pads.ci.uchicago.edu

Modified: trunk/tests/mpi/README.txt
===================================================================
--- trunk/tests/suite.sh	2011-04-04 17:57:09 UTC (rev 4262)
+++ trunk/tests/suite.sh	2011-04-04 18:00:30 UTC (rev 4263)
@@ -6,9 +6,9 @@
 # subdirectory called run-DATE, and generate useful HTML output and
 # tests.log
 
-# Usage: nightly.sh <options>* <GROUPLIST>
+# Usage: suite.sh <options>* <GROUPLIST>
 
 # Run nightly.sh -h for quick help
 # When something goes wrong, find and check tests.log or use -v
 # Code is checked out into TOPDIR (PWD by default) (PATH is not used)
 # The variables COG_VERSION and SWIFT_VERSION must be set for code checkout
@@ -58,9 +58,9 @@
 # Background processes are used so that hung Swift jobs can be killed
 # These are the background processes (PIDs are tracked)
 # Note that PID management has not yet been perfected.  Check ps
 # in error cases, especially if you kill nightly.sh .
 #
-# nightly.sh
+# suite.sh
 # +-monitor()
 #   +-sleep
 # +-process_exec()
@@ -70,7 +70,7 @@
 # FAILURE CASES
 # Some cases are designed to cause Swift to crash.  These
 # SwiftScripts contain the token THIS-SCRIPT-SHOULD-FAIL somewhere.
 # The response of nightly.sh to the exit code of these Swift
 # executions is reversed.
 
 # SCHEDULERS
@@ -88,12 +88,12 @@
 # E.g., providers/local-pbs/PADS
 
 # WARNINGS
 # nightly.sh uses shopt
 
 shopt -s nullglob
 
 printhelp() {
-  echo "nightly.sh <options> <output>"
+  echo "suite.sh <options> <output>"
   echo ""
   echo "usage:"
   printf "\t -a         Do not run ant dist             \n"
@@ -196,7 +196,7 @@
 
 MASTER_PID=$$
 
 # PIDs to kill if nightly.sh is killed:
 PROCESS_PID=
 MONITOR_PID=
 
@@ -668,7 +668,7 @@
   fi
 
   sleep 1
-  MSG="nightly.sh: monitor: killed: exceeded $TIMEOUT seconds"
+  MSG="suite.sh: monitor: killed: exceeded $TIMEOUT seconds"
   echo "$MSG" >> $OUTPUT
 
   return 1
@@ -6,9 +6,9 @@
 
-# Run nightly.sh -h for quick help
+# Run suite.sh -h for quick help
 # When something goes wrong, find and check tests.log or use -v
 # Code is checked out into TOPDIR (PWD by default) (PATH is not used)
@@ -58,9 +58,9 @@
 # These are the background processes (PIDs are tracked)
 # Note that PID management has not yet been perfected.  Check ps
-# in error cases, especially if you kill nightly.sh .
+# in error cases, especially if you kill suite.sh .
 #
@@ -70,7 +70,7 @@
 # Some cases are designed to cause Swift to crash.  These
 # SwiftScripts contain the token THIS-SCRIPT-SHOULD-FAIL somewhere.
-# The response of nightly.sh to the exit code of these Swift
+# The response of suite.sh to the exit code of these Swift
 # executions is reversed.
 
@@ -88,12 +88,12 @@
 
 # WARNINGS
-# nightly.sh uses shopt
+# suite.sh uses shopt
 
 shopt -s nullglob
@@ -196,7 +196,7 @@
 MASTER_PID=$$
 
-# PIDs to kill if nightly.sh is killed:
+# PIDs to kill if suite.sh is killed:
 PROCESS_PID=
 MONITOR_PID=




More information about the Swift-commit mailing list